@@ -16,6 +16,11 @@ def init(path):
     Initialize a default site structure
     """
     basepath = os.path.dirname(path)
+    if not os.path.exists(basepath):
+        os.makedirs(basepath)
+    if not os.path.exists(path):
+        with open(path, 'w+') as f:
+            pass
     if not os.path.exists(os.path.join(basepath, 'content')):
         os.mkdir(os.path.join(basepath, 'content'))
 
